@@ -1,4 +1,4 @@
-/* $Id: afile.c 3905 2015-04-10 11:10:14Z mskala $ */
+/* $Id: afile.c 4040 2015-06-20 14:03:08Z mskala $ */
 /*
  * File abstraction for FontAnvil
  * Copyright (C) 2015  Matthew Skala
@@ -277,8 +277,8 @@ static double scan_double(AFILE *f,int *error) {
       /* digits after decimal point */
       c=agetc(f);
       while ((c>='0') && (c<='9')) {
-	 rval+=((c-'0')*fraction);
 	 fraction/=10.0;
+	 rval+=((c-'0')*fraction);
 	 *error=0;
 	 c=agetc(f);
       }
@@ -376,6 +376,7 @@ int afscanf(AFILE *f,const char *r,...) {
        case '\t':
        case '\v':
 	 convspec=' ';
+	 rptr++;
 	 break;
 
        default:
@@ -652,6 +653,34 @@ int afscanf(AFILE *f,const char *r,...) {
    return (rval==0 && error)?-1:rval;
 }
 
+ssize_t agetline(char **lineptr,size_t *buf_size,AFILE *f) {
+   size_t n=0;
+   int c;
+
+   if (*lineptr==NULL)
+     *buf_size=0;
+   
+   while (1) {
+      if (n+1>=*buf_size) {
+	 *buf_size=(5*n)/4;
+	 if (*buf_size<80)
+	   *buf_size=80;
+	 *lineptr=(char *)realloc(*lineptr,*buf_size);
+      }
+      c=agetc(f);
+
+      if (c<0)
+	break;
+      
+      (*lineptr)[n++]=c;
+      if (c=='\n')
+	break;
+   }
+   
+   (*lineptr)[n]='\0';
+   return c>=0?n:-1;
+}
+
 /**********************************************************************/
 
 typedef struct _FP_AFILE {
@@ -755,7 +784,7 @@ static int mem_fclose(AFILE *f) {
 }
 
 static int mem_feof(AFILE *f) {
-   return ((MEM_AFILE *)f)->ptr==((MEM_AFILE *)f)->used;
+   return ((MEM_AFILE *)f)->ptr>((MEM_AFILE *)f)->used;
 }
 
 static int mem_zero(AFILE *f) {
@@ -820,6 +849,10 @@ static size_t mem_fread(void *ptr,size_t size,size_t nmemb,AFILE *f) {
      return -1;
    if ((size<=0) || (nmemb<=0))
      return 0;
+   if (((MEM_AFILE *)f)->used==((MEM_AFILE *)f)->ptr) {
+      ((MEM_AFILE *)f)->ptr++;
+      return -1; /* make "end of file" true */
+   }
 
    rsize=size*nmemb;
    if (rsize>((MEM_AFILE *)f)->used-((MEM_AFILE *)f)->ptr) {
@@ -862,8 +895,8 @@ static int mem_ungetc(int c,AFILE *f) {
    if (((MEM_AFILE *)f)->ptr>((MEM_AFILE *)f)->used)
      ((MEM_AFILE *)f)->used=((MEM_AFILE *)f)->ptr;
 
-   if (((MEM_AFILE *)f)->used>=((MEM_AFILE *)f)->allocated)
-     mem_resize((MEM_AFILE *)f,((MEM_AFILE *)f)->used+1);
+   if (((MEM_AFILE *)f)->used+2>((MEM_AFILE *)f)->allocated)
+     mem_resize((MEM_AFILE *)f,((MEM_AFILE *)f)->used+2);
    
    if (((MEM_AFILE *)f)->used>=((MEM_AFILE *)f)->ptr)
      memmove(((MEM_AFILE *)f)->buffer+((MEM_AFILE *)f)->ptr+1,
