@@ -1,6 +1,7 @@
-/* $Id: autotrace.c 3881 2015-03-29 11:53:17Z mskala $ */
-/* Copyright (C) 2000-2012 by George Williams */
-/*
+/* $Id: autotrace.c 4064 2015-06-25 14:15:40Z mskala $ */
+/* Copyright (C) 2000-2012  George Williams
+ * Copyright (C) 2015  Matthew Skala
+ *
  * Redistribution and use in source and binary forms, with or without
  * modification, are permitted provided that the following conditions are met:
  *
@@ -240,7 +241,7 @@ static char *mytempdir(void) {
    while (1) {
       sprintf(eon, "%04X_mf%d", getpid(), ++cnt);
       if (mkdir(buffer, 0770)==0)
-	 return (copy(buffer));
+	 return (fastrdup(buffer));
       else if (errno != EEXIST)
 	 return (NULL);
       if (++tries > 100)
@@ -712,7 +713,7 @@ static char *FindGfFile(char *tempdir) {
 	    strcpy(buffer, tempdir);
 	    strcat(buffer, "/");
 	    strcat(buffer, ent->d_name);
-	    ret=copy(buffer);
+	    ret=fastrdup(buffer);
 	    break;
 	 }
       }
@@ -745,7 +746,7 @@ static void cleantempdir(char *tempdir) {
 	 /*  which might mean we could not read it properly. So save up the */
 	 /*  things we need to delete and trash them later */
 	 if (cnt < 99)
-	    todelete[cnt++]=copy(buffer);
+	    todelete[cnt++]=fastrdup(buffer);
       }
       closedir(temp);
       todelete[cnt]=NULL;
@@ -759,7 +760,7 @@ static void cleantempdir(char *tempdir) {
 
 void MfArgsInit(void) {
    if (mf_args==NULL)
-      mf_args=copy("\\scrollmode; mode=proof ; mag=2; input");
+      mf_args=fastrdup("\\scrollmode; mode=proof ; mag=2; input");
 }
 
 static char *MfArgs(void) {
