@@ -1,6 +1,7 @@
-/* $Id: autowidth.c 3881 2015-03-29 11:53:17Z mskala $ */
-/* Copyright (C) 2000-2012 by George Williams */
-/*
+/* $Id: autowidth.c 4064 2015-06-25 14:15:40Z mskala $ */
+/* Copyright (C) 2000-2012  George Williams
+ * Copyright (C) 2015  Matthew Skala
+ *
  * Redistribution and use in source and binary forms, with or without
  * modification, are permitted provided that the following conditions are met:
  *
@@ -1064,7 +1065,7 @@ static int AW_ReadKernPairFile(char *fn,WidthInfo *wi) {
    unichar_t buffer[300];
    struct kernsets ks;
 
-   filename=utf82def_copy(fn);
+   filename=fastrdup(fn);
    file=afopen(filename, "r");
    free(filename);
    if (file==NULL) {
@@ -1509,7 +1510,7 @@ int AutoKernScript(FontViewBase * fv, int spacing, int threshold,
       AW_ScriptSerifChecker(&wi);
       AW_InitCharPairs(&wi);
    } else {
-      if (!AW_ReadKernPairFile(copy(kernfile), &wi))
+      if (!AW_ReadKernPairFile(strdup(kernfile), &wi))
 	 return (false);
    }
    wi.done=true;
