@@ -1,6 +1,7 @@
-/* $Id: bitmapchar.c 3871 2015-03-27 08:01:10Z mskala $ */
-/* Copyright (C) 2000-2012 by George Williams */
-/*
+/* $Id: bitmapchar.c 4064 2015-06-25 14:15:40Z mskala $ */
+/* Copyright (C) 2000-2012  George Williams
+ * Copyright (C) 2015  Matthew Skala
+ *
  * Redistribution and use in source and binary forms, with or without
  * modification, are permitted provided that the following conditions are met:
  *
@@ -83,9 +84,6 @@ struct std_bdf_props StandardProps[]={
    {"FIGURE_WIDTH", prt_int | prt_property, true},
    {"AVG_LOWERCASE_WIDTH", prt_int | prt_property, true},
    {"AVG_UPPERCASE_WIDTH", prt_int | prt_property, true},
-#ifdef FONTANVIL_CONFIG_BDF_GLYPH_RANGES
-   {"_XFREE86_GLYPH_RANGES", prt_string | prt_property, true},
-#endif
    {"WEIGHT", prt_uint | prt_property, false},
    {"DESTINATION", prt_uint | prt_property, false},
    {"MIN_SPACE", prt_int | prt_property, false},
@@ -172,7 +170,7 @@ static void BDFPropAddString(BDFFont *bdf,char *keyword,char *value,
 	    realloc(bdf->props,
 		    (bdf->prop_max += 10) * sizeof(BDFProperties));
       ++bdf->prop_cnt;
-      bdf->props[i].name=copy(keyword);
+      bdf->props[i].name=fastrdup(keyword);
    }
    if (strcmp(keyword, "FONT")==0)
       bdf->props[i].type=prt_atom;
@@ -180,7 +178,7 @@ static void BDFPropAddString(BDFFont *bdf,char *keyword,char *value,
       bdf->props[i].type=prt_string;
    else
       bdf->props[i].type=prt_string | prt_property;
-   bdf->props[i].u.str=copy(value);
+   bdf->props[i].u.str=fastrdup(value);
 }
 
 static void BDFPropAddInt(BDFFont *bdf,char *keyword,int value,
@@ -203,7 +201,7 @@ static void BDFPropAddInt(BDFFont *bdf,char *keyword,int value,
 	    realloc(bdf->props,
 		    (bdf->prop_max += 10) * sizeof(BDFProperties));
       ++bdf->prop_cnt;
-      bdf->props[i].name=copy(keyword);
+      bdf->props[i].name=fastrdup(keyword);
    }
    if (IsUnsignedBDFKey(keyword))
       bdf->props[i].type=prt_uint | prt_property;
@@ -258,34 +256,16 @@ static void BDFPropAppendString(BDFFont *bdf,char *keyword,char *value) {
       bdf->props =
 	 realloc(bdf->props, (bdf->prop_max += 10) * sizeof(BDFProperties));
    ++bdf->prop_cnt;
-   bdf->props[i].name=copy(keyword);
+   bdf->props[i].name=fastrdup(keyword);
    if (strcmp(keyword, "COMMENT")==0)
       bdf->props[i].type=prt_string;
    else if (strcmp(keyword, "FONT")==0)
       bdf->props[i].type=prt_atom;
    else
       bdf->props[i].type=prt_string | prt_property;
-   bdf->props[i].u.str=copy(value);
+   bdf->props[i].u.str=fastrdup(value);
 }
 
-#ifdef FONTANVIL_CONFIG_BDF_GLYPH_RANGES
-static void BDFPropClearKey(BDFFont *bdf,char *keyword) {
-   int i, j;
-
-   for (i=j=0; i < bdf->prop_cnt; ++i) {
-      if (strcmp(bdf->props[i].name, keyword)==0) {
-	 free(bdf->props[i].name);
-	 if ((bdf->props[i].type & ~prt_property)==prt_string ||
-	     (bdf->props[i].type & ~prt_property)==prt_atom)
-	    free(bdf->props[i].u.str);
-      } else if (i != j) {
-	 bdf->props[j++]=bdf->props[i];
-      } else
-	 ++j;
-   }
-}
-#endif /* FONTANVIL_CONFIG_BDF_GLYPH_RANGES */
-
 static int BDFPropReplace(BDFFont *bdf,const char *key,const char *value) {
    int i;
 
@@ -304,7 +284,7 @@ static int BDFPropReplace(BDFFont *bdf,const char *key,const char *value) {
 	       (bdf->props[i].type & prt_property) | prt_string;
 	 pt=strchr(value, '\n');
 	 if (pt==NULL)
-	    bdf->props[i].u.str=copy(value);
+	    bdf->props[i].u.str=fastrdup(value);
 	 else
 	    bdf->props[i].u.str=copyn(value, pt - value);
 	 return (true);
@@ -708,59 +688,6 @@ void Default_XLFD(BDFFont * bdf, EncMap * map, int res) {
    BDFPropAddString(bdf, "FONT", buffer, NULL);
 }
 
-static int GenerateGlyphRanges(BDFFont *font) {
-#ifdef FONTANVIL_CONFIG_BDF_GLYPH_RANGES
-   char buffer[300], *pt, *end, add[30];
-
-   int i, j, max, cnt=0;
-
-   /* I gather that the _XFREE86_GLYPH_RANGES property has been dropped */
-   /*  because it was felt that the metrics data would allow users to */
-   /*  determine whether a character was in the font or not. I'm not in */
-   /*  complete agreement with that argument because there are several */
-   /*  zero-width spaces whose presence is not specified by the metrics */
-   /*  but it is almost irrelevant whether they are present or not (though */
-   /*  guessing wrong would present you with a "DEFAULT_CHAR" rather than */
-   /*  nothing) */
-
-   if (map->enc->is_unicodebmp || map->enc->is_unicodefull)
-      max=map->enc->char_cnt;
-   else
-      return (0);
-   BDFPropClearKey(font, "_XFREE86_GLYPH_RANGES");
-   pt=buffer;
-   end=pt + sizeof(buffer);
-   for (i=0; i < font->glyphcnt && i < max; ++i)
-      if (!IsntBDFChar(font->glyphs[i])) {
-	 for (j=i + 1;
-	      j < font->glyphcnt && j < max && !IsntBDFChar(font->glyphs[j]);
-	      ++j);
-	 --j;
-	 if (j==i)
-	    sprintf(add, "%d ", i);
-	 else
-	    sprintf(add, "%d_%d ", i, j);
-	 i=j;
-	 if (pt + strlen(add) >= end) {
-	    pt[-1]='\0';	/* was a space */
-	    BDFPropAppendString(font, "_XFREE86_GLYPH_RANGES", buffer);
-	    pt=buffer;
-	    ++cnt;
-	 }
-	 strcpy(pt, add);
-	 pt += strlen(pt);
-      }
-   if (pt != buffer) {
-      pt[-1]='\0';		/* was a space */
-      BDFPropAppendString(font, "_XFREE86_GLYPH_RANGES", buffer);
-      ++cnt;
-   }
-   return (cnt);
-#else
-   return (0);
-#endif /* FONTANVIL_CONFIG_BDF_GLYPH_RANGES */
-}
-
 void Default_Properties(BDFFont * bdf, EncMap * map, char *onlyme) {
    char *xlfd=BdfPropHasString(bdf, "FONT", NULL);
 
@@ -945,11 +872,6 @@ void Default_Properties(BDFFont * bdf, EncMap * map, char *onlyme) {
 		       onlyme);
    }
 
-   /* Normally this does nothing, but fontanvil may be configured to generate */
-   /*  the obsolete _XFREE86_GLYPH_RANGES property, and if so this will */
-   /*  generate them */
-   GenerateGlyphRanges(bdf);
-
    /* MIN_SPACE, MAX_SPACE & END_SPACE are judgement calls and I shan't default them */
    /* also SMALL_CAP_SIZE, STRIKEOUT_ASCENT, STRIKEOUT_DESCENT, DESTINATION */
    /* WEIGHT requires a knowlege of stem sizes and I'm not going to do that */
