@@ -1,6 +1,7 @@
-/* $Id: bvedit.c 3872 2015-03-27 09:43:03Z mskala $ */
-/* Copyright (C) 2000-2012 by George Williams */
-/*
+/* $Id: bvedit.c 4064 2015-06-25 14:15:40Z mskala $ */
+/* Copyright (C) 2000-2012  George Williams
+ * Copyright (C) 2015  Matthew Skala
+ *
  * Redistribution and use in source and binary forms, with or without
  * modification, are permitted provided that the following conditions are met:
  *
@@ -1039,7 +1040,7 @@ BDFFont *BitmapFontScaleTo(BDFFont * old, int to) {
    new->pixelsize=to;
    new->ascent=(old->ascent * to + .5) / old->pixelsize;
    new->descent=to - new->ascent;
-   new->foundry=copy(old->foundry);
+   new->foundry=fastrdup(old->foundry);
    new->res=-1;
    for (i=0; i < old->glyphcnt; ++i) {
       if (old->clut==NULL) {
