@@ -1,6 +1,7 @@
-/* $Id: dumppfa.c 3995 2015-06-03 12:34:24Z mskala $ */
-/* Copyright (C) 2000-2012 by George Williams */
-/*
+/* $Id: dumppfa.c 4071 2015-06-29 09:11:43Z mskala $ */
+/* Copyright (C) 2000-2012  George Williams
+ * Copyright (C) 2015  Matthew Skala
+ *
  * Redistribution and use in source and binary forms, with or without
  * modification, are permitted provided that the following conditions are met:
  *
@@ -184,8 +185,8 @@ struct psdict *PSDictCopy(struct psdict *dict) {
    ret->keys=calloc(ret->cnt, sizeof(char *));
    ret->values=calloc(ret->cnt, sizeof(char *));
    for (i=0; i < dict->next; ++i) {
-      ret->keys[i]=copy(dict->keys[i]);
-      ret->values[i]=copy(dict->values[i]);
+      ret->keys[i]=fastrdup(dict->keys[i]);
+      ret->values[i]=fastrdup(dict->values[i]);
    }
 
    return (ret);
@@ -255,12 +256,12 @@ int PSDictChangeEntry(struct psdict *dict,char *key,char *newval) {
 	 dict->keys=realloc(dict->keys,dict->cnt*sizeof(char *));
 	 dict->values=realloc(dict->values,dict->cnt*sizeof(char *));
       }
-      dict->keys[dict->next]=copy(key);
+      dict->keys[dict->next]=fastrdup(key);
       dict->values[dict->next]=NULL;
       ++dict->next;
    }
    free(dict->values[i]);
-   dict->values[i]=copy(newval);
+   dict->values[i]=fastrdup(newval);
    return (i);
 }
 
@@ -1832,7 +1833,7 @@ static void dumprequiredfontinfo(AFILE *f, SplineFont *sf, int format,
       cnt += 7;
 
    if (sf->uniqueid==0)
-      uniqueid=4000000 + (rand() & 0x3ffff);
+      uniqueid=4000000+(sfmt_genrand_uint32(&fa_sfmt)&0x3ffff);
    else
       uniqueid=sf->uniqueid;
    sf->tempuniqueid=uniqueid;
@@ -2099,7 +2100,7 @@ static void dumptype42(AFILE *out,SplineFont *sf,int format,int flags,
    dumpfontinfo(out, sf, format);
 
    if (sf->uniqueid==0)
-      uniqueid=4000000 + (rand() & 0x3ffff);
+      uniqueid=4000000+(sfmt_genrand_uint32(&fa_sfmt)&0x3ffff);
    else
       uniqueid=sf->uniqueid;
    sf->tempuniqueid=uniqueid;
@@ -2555,7 +2556,7 @@ static int dumpcidstuff(AFILE *out,SplineFont *cidmaster,int flags,
    if (cidmaster->use_uniqueid) {
       afprintf(out, "/UIDBase %d def\n",
 	      cidmaster->uniqueid?cidmaster->uniqueid:4000000 +
-	      (rand() & 0x3ffff));
+	      (sfmt_genrand_uint32(&fa_sfmt)&0x3ffff));
       if (cidmaster->xuid != NULL && cidmaster->use_xuid) {
 	 afprintf(out, "/XUID %s def\n", cidmaster->xuid);
 	 /* SFIncrementXUID(cidmaster); *//* Unique ID managment in CID fonts is too complex for this simple trick to work */
