@@ -1,6 +1,7 @@
-/* $Id: fontviewbase.c 3872 2015-03-27 09:43:03Z mskala $ */
-/* Copyright (C) 2000-2012 by George Williams */
-/*
+/* $Id: fontviewbase.c 4064 2015-06-25 14:15:40Z mskala $ */
+/* Copyright (C) 2000-2012  George Williams
+ * Copyright (C) 2015  Matthew Skala
+ *
  * Redistribution and use in source and binary forms, with or without
  * modification, are permitted provided that the following conditions are met:
  *
@@ -1438,11 +1439,11 @@ static void _FVRevert(FontViewBase *fv,int tobackup) {
 
    if (temp->filename!=NULL) {
       free(temp->filename);
-      temp->filename=copy(old->filename);
+      temp->filename=fastrdup(old->filename);
    }
    if (temp->origname!=NULL) {
       free(temp->origname);
-      temp->origname=copy(old->origname);
+      temp->origname=fastrdup(old->origname);
    }
 
    temp->compression=old->compression;
