@@ -1,6 +1,7 @@
-/* $Id: http.c 3881 2015-03-29 11:53:17Z mskala $ */
-/* Copyright (C) 2007-2012 by George Williams */
-/*
+/* $Id: http.c 4071 2015-06-29 09:11:43Z mskala $ */
+/* Copyright (C) 2007-2012  George Williams
+ * Copyright (C) 2015  Matthew Skala
+ *
  * Redistribution and use in source and binary forms, with or without
  * modification, are permitted provided that the following conditions are met:
  *
@@ -88,13 +89,16 @@ static int findhost(struct sockaddr_in *addr,char *hostname) {
 	 return (0);
    }
    for (i=0; hostent->h_addr_list[i] != NULL; ++i);
-   memcpy(&addr->sin_addr, hostent->h_addr_list[rand() % i],
+   memcpy(&addr->sin_addr,
+	  hostent->h_addr_list[sfmt_genrand_uint32(&fa_sfmt)%i],
 	  hostent->h_length);
    if (hostent->h_length < sizeof(last_addr)) {	/* Cache the last hostname, in case they ask for it again */
       free(last_host);
-      last_host=copy(hostname);
+      last_host=fastrdup(hostname);
       last_len=hostent->h_length;
-      memcpy(last_addr, hostent->h_addr_list[rand() % i], hostent->h_length);
+      memcpy(last_addr,
+	     hostent->h_addr_list[sfmt_genrand_uint32(&fa_sfmt)%i],
+	     hostent->h_length);
    }
    endhostent();
    return (1);
@@ -323,7 +327,7 @@ static char *decomposeURL(const char *url,char **host,int *port,
    pt=strstr(url, "://");
    if (pt==NULL) {
       *host=NULL;
-      return (copy(url));
+      return (fastrdup(url));
    }
    strncpy(proto, url, pt - url < sizeof(proto) ? pt - url : sizeof(proto));
    proto[(pt - url)]='\0';
@@ -332,9 +336,9 @@ static char *decomposeURL(const char *url,char **host,int *port,
    pt2=strchr(pt, '/');
    if (pt2==NULL) {
       pt2=pt + strlen(pt);
-      path=copy("/");
+      path=fastrdup("/");
    } else {
-      path=copy(pt2);
+      path=fastrdup(pt2);
    }
 
    upt=strchr(pt, '@');
@@ -575,11 +579,11 @@ static int FtpURLAndTempFile(char *url,AFILE ** to,AFILE *from) {
    free(host);
 
    if (username==NULL) {
-      username=copy("anonymous");
+      username=fastrdup("anonymous");
       if (password==NULL)
-	 password=copy("FontAnvil");
+	 password=fastrdup("FontAnvil");
    } else if (password==NULL)
-      password=copy("");
+      password=fastrdup("");
 
    sprintf(cmd, "USER %s\r\n", username);
    if (ftpsendr(soc, cmd, databuf, datalen)==-1) {
