@@ -1,6 +1,7 @@
-/* $Id: parsettfbmf.c 3871 2015-03-27 08:01:10Z mskala $ */
-/* Copyright (C) 2000-2012 by George Williams */
-/*
+/* $Id: parsettfbmf.c 4064 2015-06-25 14:15:40Z mskala $ */
+/* Copyright (C) 2000-2012  George Williams
+ * Copyright (C) 2015  Matthew Skala
+ *
  * Redistribution and use in source and binary forms, with or without
  * modification, are permitted provided that the following conditions are met:
  *
@@ -591,7 +592,7 @@ void TTFLoadBitmaps(AFILE *ttf, struct ttfinfo *info, int onlyone) {
 	 sprintf(buf, "%d", sizes[i].ppem);
       else
 	 sprintf(buf, "%d@%d", sizes[i].ppem, sizes[i].depth);
-      choices[i]=copy(buf);
+      choices[i]=fastrdup(buf);
    }
    /* When loading a ttf font with only bitmaps, and there's only one strike */
    /*  then just load that strike. Don't ask */
