@@ -1,6 +1,7 @@
-/* $Id: woff.c 3881 2015-03-29 11:53:17Z mskala $ */
-/* Copyright (C) 2010-2012 by George Williams */
-/*
+/* $Id: woff.c 4054 2015-06-25 11:15:19Z mskala $ */
+/* Copyright (C) 2010-2012  George Williams
+ * Copyright (C) 2015  Matthew Skala
+ *
  * Redistribution and use in source and binary forms, with or without
  * modification, are permitted provided that the following conditions are met:
  *
@@ -59,10 +60,6 @@ int WriteWOFFFont(char *fontname, SplineFont *sf, enum fontformat format,
    return (1);
 }
 
-int CanWoff(void) {
-   return (0);
-}
-
 #else /* ! _NO_LIBPNG */
 
 #   include <zlib.h>
@@ -549,8 +546,4 @@ int WriteWOFFFont(char *fontname, SplineFont *sf, enum fontformat format,
    return (ret);
 }
 
-int CanWoff(void) {
-   return (true);
-}
-
 #endif /* ! _NO_LIBPNG */
