@@ -1,4 +1,4 @@
-/* $Id: giohosts.c 2946 2014-03-11 19:55:39Z mskala $ */
+/* $Id: giohosts.c 4064 2015-06-25 14:15:40Z mskala $ */
 /* Copyright (C) 2000-2012 by George Williams */
 /*
  * Redistribution and use in source and binary forms, with or without
@@ -65,12 +65,12 @@ char *GIO_PasswordCache(char *proto, char *host, char *username,
 	  strcasecmp(host, pc[i].host) == 0 &&
 	  strcmp(username, pc[i].username) == 0) {
 	 if (password == NULL) {
-	    password = copy(pc[i].password);
+	    password = fastrdup(pc[i].password);
 	    goto leave;
 	 }
 	 if (strcmp(password, pc[i].password) != 0) {
 	    free(pc[i].password);
-	    pc[i].password = copy(password);
+	    pc[i].password = fastrdup(password);
 	 }
 	 goto leave;
       }
@@ -81,10 +81,10 @@ char *GIO_PasswordCache(char *proto, char *host, char *username,
 
    if (pc_cnt >= pc_max)
       pc = realloc(pc, (pc_max += 10) * sizeof(struct passwd_cache));
-   pc[pc_cnt].proto = copy(proto);
-   pc[pc_cnt].host = copy(host);
-   pc[pc_cnt].username = copy(username);
-   pc[pc_cnt].password = copy(password);
+   pc[pc_cnt].proto = fastrdup(proto);
+   pc[pc_cnt].host = fastrdup(host);
+   pc[pc_cnt].username = fastrdup(username);
+   pc[pc_cnt].password = fastrdup(password);
    ++pc_cnt;
  leave:
 #ifdef HAVE_PTHREAD_H
